@@ -6,10 +6,11 @@ Type annotations for mgn service client.
 Usage::
 
     ```python
-    import boto3
-    from mypy_boto3_mgn import mgnClient
+    from boto3.session import Session
+    from mypy_boto3_mgn.client import mgnClient
 
-    client: mgnClient = boto3.client("mgn")
+    session = Session()
+    client: mgnClient = session.client("mgn")
     ```
 """
 import sys
@@ -22,6 +23,7 @@ from .literals import (
     ReplicationConfigurationDataPlaneRoutingType,
     ReplicationConfigurationDefaultLargeStagingDiskTypeType,
     ReplicationConfigurationEbsEncryptionType,
+    ReplicationTypeType,
     TargetInstanceTypeRightSizingMethodType,
 )
 from .paginator import (
@@ -29,6 +31,7 @@ from .paginator import (
     DescribeJobsPaginator,
     DescribeReplicationConfigurationTemplatesPaginator,
     DescribeSourceServersPaginator,
+    DescribeVcenterClientsPaginator,
 )
 from .type_defs import (
     ChangeServerLifeCycleStateSourceServerLifecycleTypeDef,
@@ -38,6 +41,7 @@ from .type_defs import (
     DescribeReplicationConfigurationTemplatesResponseTypeDef,
     DescribeSourceServersRequestFiltersTypeDef,
     DescribeSourceServersResponseTypeDef,
+    DescribeVcenterClientsResponseTypeDef,
     LaunchConfigurationTypeDef,
     LicensingTypeDef,
     ListTagsForResourceResponseTypeDef,
@@ -73,6 +77,7 @@ class Exceptions:
     ConflictException: Type[BotocoreClientError]
     InternalServerException: Type[BotocoreClientError]
     ResourceNotFoundException: Type[BotocoreClientError]
+    ServiceQuotaExceededException: Type[BotocoreClientError]
     ThrottlingException: Type[BotocoreClientError]
     UninitializedAccountException: Type[BotocoreClientError]
     ValidationException: Type[BotocoreClientError]
@@ -80,7 +85,7 @@ class Exceptions:
 
 class mgnClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mgn.html#mgn.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html)
     """
 
@@ -90,13 +95,16 @@ class mgnClient(BaseClient):
     def exceptions(self) -> Exceptions:
         """
         mgnClient exceptions.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mgn.html#mgn.Client.exceptions)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#exceptions)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mgn.html#mgn.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#can_paginate)
         """
 
@@ -110,7 +118,7 @@ class mgnClient(BaseClient):
         Allows the user to set the SourceServer.LifeCycle.state property for specific
         Source Server IDs to one of the following: READY_FOR_TEST or READY_FOR_CUTOVER.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.change_server_life_cycle_state)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mgn.html#mgn.Client.change_server_life_cycle_state)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#change_server_life_cycle_state)
         """
 
@@ -134,7 +142,7 @@ class mgnClient(BaseClient):
         """
         Creates a new ReplicationConfigurationTemplate.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.create_replication_configuration_template)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mgn.html#mgn.Client.create_replication_configuration_template)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#create_replication_configuration_template)
         """
 
@@ -142,7 +150,7 @@ class mgnClient(BaseClient):
         """
         Deletes a single Job by ID.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.delete_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mgn.html#mgn.Client.delete_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#delete_job)
         """
 
@@ -150,12 +158,10 @@ class mgnClient(BaseClient):
         self, *, replicationConfigurationTemplateID: str
     ) -> Dict[str, Any]:
         """
-        Deletes a single Replication Configuration Template by ID See also: `AWS API
-        Documentation <https://docs.aws.amazon.com/goto/WebAPI/mgn-2020-02-
-        26/DeleteReplicationConfigurationTemplate>`_ **Request Syntax** response =
-        client.delete_replication_configuration_template( replicatio...
+        Deletes a single Replication Configuration Template by ID See also: [AWS API
+        Documentation](https://docs.aws.amazon.com/goto/WebAPI/mgn-2020-02-26/DeleteReplicationConfigurationTemplate).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.delete_replication_configuration_template)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mgn.html#mgn.Client.delete_replication_configuration_template)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#delete_replication_configuration_template)
         """
 
@@ -163,17 +169,25 @@ class mgnClient(BaseClient):
         """
         Deletes a single source server by ID.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.delete_source_server)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mgn.html#mgn.Client.delete_source_server)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#delete_source_server)
         """
 
+    def delete_vcenter_client(self, *, vcenterClientID: str) -> None:
+        """
+        Deletes a single vCenter client by ID.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mgn.html#mgn.Client.delete_vcenter_client)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#delete_vcenter_client)
+        """
+
     def describe_job_log_items(
         self, *, jobID: str, maxResults: int = ..., nextToken: str = ...
     ) -> DescribeJobLogItemsResponseTypeDef:
         """
         Retrieves detailed Job log with paging.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.describe_job_log_items)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mgn.html#mgn.Client.describe_job_log_items)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#describe_job_log_items)
         """
 
@@ -187,7 +201,7 @@ class mgnClient(BaseClient):
         """
         Returns a list of Jobs.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.describe_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mgn.html#mgn.Client.describe_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#describe_jobs)
         """
 
@@ -201,7 +215,7 @@ class mgnClient(BaseClient):
         """
         Lists all ReplicationConfigurationTemplates, filtered by Source Server IDs.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.describe_replication_configuration_templates)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mgn.html#mgn.Client.describe_replication_configuration_templates)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#describe_replication_configuration_templates)
         """
 
@@ -215,17 +229,27 @@ class mgnClient(BaseClient):
         """
         Retrieves all SourceServers or multiple SourceServers by ID.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.describe_source_servers)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mgn.html#mgn.Client.describe_source_servers)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#describe_source_servers)
         """
 
+    def describe_vcenter_clients(
+        self, *, maxResults: int = ..., nextToken: str = ...
+    ) -> DescribeVcenterClientsResponseTypeDef:
+        """
+        Lists all vCenter clients.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mgn.html#mgn.Client.describe_vcenter_clients)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#describe_vcenter_clients)
+        """
+
     def disconnect_from_service(
         self, *, sourceServerID: str
     ) -> SourceServerResponseMetadataTypeDef:
         """
         Disconnects specific Source Servers from Application Migration Service.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.disconnect_from_service)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mgn.html#mgn.Client.disconnect_from_service)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#disconnect_from_service)
         """
 
@@ -233,7 +257,7 @@ class mgnClient(BaseClient):
         """
         Finalizes the cutover immediately for specific Source Servers.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.finalize_cutover)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mgn.html#mgn.Client.finalize_cutover)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#finalize_cutover)
         """
 
@@ -247,7 +271,7 @@ class mgnClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mgn.html#mgn.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#generate_presigned_url)
         """
 
@@ -255,7 +279,7 @@ class mgnClient(BaseClient):
         """
         Lists all LaunchConfigurations available, filtered by Source Server IDs.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.get_launch_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mgn.html#mgn.Client.get_launch_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#get_launch_configuration)
         """
 
@@ -265,7 +289,7 @@ class mgnClient(BaseClient):
         """
         Lists all ReplicationConfigurations, filtered by Source Server ID.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.get_replication_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mgn.html#mgn.Client.get_replication_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#get_replication_configuration)
         """
 
@@ -273,7 +297,7 @@ class mgnClient(BaseClient):
         """
         Initialize Application Migration Service.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.initialize_service)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mgn.html#mgn.Client.initialize_service)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#initialize_service)
         """
 
@@ -281,7 +305,7 @@ class mgnClient(BaseClient):
         """
         List all tags for your Application Migration Service resources.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mgn.html#mgn.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#list_tags_for_resource)
         """
 
@@ -290,7 +314,7 @@ class mgnClient(BaseClient):
         Archives specific Source Servers by setting the SourceServer.isArchived property
         to true for specified SourceServers by ID.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.mark_as_archived)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mgn.html#mgn.Client.mark_as_archived)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#mark_as_archived)
         """
 
@@ -300,7 +324,7 @@ class mgnClient(BaseClient):
         Handshake for specified SourceServer IDs, regardless of when the previous
         initiation started.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.retry_data_replication)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mgn.html#mgn.Client.retry_data_replication)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#retry_data_replication)
         """
 
@@ -310,17 +334,25 @@ class mgnClient(BaseClient):
         """
         Launches a Cutover Instance for specific Source Servers.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.start_cutover)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mgn.html#mgn.Client.start_cutover)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#start_cutover)
         """
 
+    def start_replication(self, *, sourceServerID: str) -> SourceServerResponseMetadataTypeDef:
+        """
+        Starts replication on source server by ID.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mgn.html#mgn.Client.start_replication)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#start_replication)
+        """
+
     def start_test(
         self, *, sourceServerIDs: Sequence[str], tags: Mapping[str, str] = ...
     ) -> StartTestResponseTypeDef:
         """
         Lauches a Test Instance for specific Source Servers.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.start_test)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mgn.html#mgn.Client.start_test)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#start_test)
         """
 
@@ -329,7 +361,7 @@ class mgnClient(BaseClient):
         Adds or overwrites only the specified tags for the specified Application
         Migration Service resource or resources.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mgn.html#mgn.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#tag_resource)
         """
 
@@ -339,7 +371,7 @@ class mgnClient(BaseClient):
         """
         Starts a job that terminates specific launched EC2 Test and Cutover instances.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.terminate_target_instances)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mgn.html#mgn.Client.terminate_target_instances)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#terminate_target_instances)
         """
 
@@ -348,7 +380,7 @@ class mgnClient(BaseClient):
         Deletes the specified set of tags from the specified set of Application
         Migration Service resources.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mgn.html#mgn.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#untag_resource)
         """
 
@@ -366,7 +398,7 @@ class mgnClient(BaseClient):
         """
         Updates multiple LaunchConfigurations by Source Server ID.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.update_launch_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mgn.html#mgn.Client.update_launch_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#update_launch_configuration)
         """
 
@@ -392,7 +424,7 @@ class mgnClient(BaseClient):
         """
         Allows you to update multiple ReplicationConfigurations by Source Server ID.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.update_replication_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mgn.html#mgn.Client.update_replication_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#update_replication_configuration)
         """
 
@@ -417,24 +449,34 @@ class mgnClient(BaseClient):
         """
         Updates multiple ReplicationConfigurationTemplates by ID.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.update_replication_configuration_template)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mgn.html#mgn.Client.update_replication_configuration_template)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#update_replication_configuration_template)
         """
 
+    def update_source_server_replication_type(
+        self, *, replicationType: ReplicationTypeType, sourceServerID: str
+    ) -> SourceServerResponseMetadataTypeDef:
+        """
+        Updates source server Replication Type by ID.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mgn.html#mgn.Client.update_source_server_replication_type)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#update_source_server_replication_type)
+        """
+
     @overload
     def get_paginator(
         self, operation_name: Literal["describe_job_log_items"]
     ) -> DescribeJobLogItemsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Paginator.DescribeJobLogItems)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/paginators.html#describejoblogitemspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mgn.html#mgn.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#get_paginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["describe_jobs"]) -> DescribeJobsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Paginator.DescribeJobs)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/paginators.html#describejobspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mgn.html#mgn.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#get_paginator)
         """
 
     @overload
@@ -442,8 +484,8 @@ class mgnClient(BaseClient):
         self, operation_name: Literal["describe_replication_configuration_templates"]
     ) -> DescribeReplicationConfigurationTemplatesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Paginator.DescribeReplicationConfigurationTemplates)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/paginators.html#describereplicationconfigurationtemplatespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mgn.html#mgn.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#get_paginator)
         """
 
     @overload
@@ -451,6 +493,15 @@ class mgnClient(BaseClient):
         self, operation_name: Literal["describe_source_servers"]
     ) -> DescribeSourceServersPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Paginator.DescribeSourceServers)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/paginators.html#describesourceserverspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mgn.html#mgn.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#get_paginator)
+        """
+
+    @overload
+    def get_paginator(
+        self, operation_name: Literal["describe_vcenter_clients"]
+    ) -> DescribeVcenterClientsPaginator:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mgn.html#mgn.Client.get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#get_paginator)
         """
