@@ -12,7 +12,7 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, List, Mapping, Sequence
+from typing import Dict, List, Mapping, Sequence
 
 from .literals import (
     ChangeServerLifeCycleStateSourceServerLifecycleStateType,
@@ -32,6 +32,7 @@ from .literals import (
     ReplicationConfigurationDefaultLargeStagingDiskTypeType,
     ReplicationConfigurationEbsEncryptionType,
     ReplicationConfigurationReplicatedDiskStagingDiskTypeType,
+    ReplicationTypeType,
     TargetInstanceTypeRightSizingMethodType,
 )
 
@@ -54,6 +55,7 @@ __all__ = (
     "DeleteJobRequestRequestTypeDef",
     "DeleteReplicationConfigurationTemplateRequestRequestTypeDef",
     "DeleteSourceServerRequestRequestTypeDef",
+    "DeleteVcenterClientRequestRequestTypeDef",
     "DescribeJobLogItemsRequestRequestTypeDef",
     "DescribeJobLogItemsResponseTypeDef",
     "DescribeJobsRequestFiltersTypeDef",
@@ -64,6 +66,8 @@ __all__ = (
     "DescribeSourceServersRequestFiltersTypeDef",
     "DescribeSourceServersRequestRequestTypeDef",
     "DescribeSourceServersResponseTypeDef",
+    "DescribeVcenterClientsRequestRequestTypeDef",
+    "DescribeVcenterClientsResponseTypeDef",
     "DisconnectFromServiceRequestRequestTypeDef",
     "DiskTypeDef",
     "FinalizeCutoverRequestRequestTypeDef",
@@ -103,6 +107,7 @@ __all__ = (
     "SourceServerTypeDef",
     "StartCutoverRequestRequestTypeDef",
     "StartCutoverResponseTypeDef",
+    "StartReplicationRequestRequestTypeDef",
     "StartTestRequestRequestTypeDef",
     "StartTestResponseTypeDef",
     "TagResourceRequestRequestTypeDef",
@@ -112,6 +117,8 @@ __all__ = (
     "UpdateLaunchConfigurationRequestRequestTypeDef",
     "UpdateReplicationConfigurationRequestRequestTypeDef",
     "UpdateReplicationConfigurationTemplateRequestRequestTypeDef",
+    "UpdateSourceServerReplicationTypeRequestRequestTypeDef",
+    "VcenterClientTypeDef",
 )
 
 CPUTypeDef = TypedDict(
@@ -200,6 +207,7 @@ DataReplicationInfoTypeDef = TypedDict(
         "dataReplicationState": DataReplicationStateType,
         "etaDateTime": str,
         "lagDuration": str,
+        "lastSnapshotDateTime": str,
         "replicatedDisks": List["DataReplicationInfoReplicatedDiskTypeDef"],
     },
     total=False,
@@ -245,6 +253,13 @@ DeleteSourceServerRequestRequestTypeDef = TypedDict(
     },
 )
 
+DeleteVcenterClientRequestRequestTypeDef = TypedDict(
+    "DeleteVcenterClientRequestRequestTypeDef",
+    {
+        "vcenterClientID": str,
+    },
+)
+
 _RequiredDescribeJobLogItemsRequestRequestTypeDef = TypedDict(
     "_RequiredDescribeJobLogItemsRequestRequestTypeDef",
     {
@@ -354,6 +369,8 @@ DescribeSourceServersRequestFiltersTypeDef = TypedDict(
     "DescribeSourceServersRequestFiltersTypeDef",
     {
         "isArchived": bool,
+        "lifeCycleStates": Sequence[LifeCycleStateType],
+        "replicationTypes": Sequence[ReplicationTypeType],
         "sourceServerIDs": Sequence[str],
     },
     total=False,
@@ -391,6 +408,24 @@ DescribeSourceServersResponseTypeDef = TypedDict(
     },
 )
 
+DescribeVcenterClientsRequestRequestTypeDef = TypedDict(
+    "DescribeVcenterClientsRequestRequestTypeDef",
+    {
+        "maxResults": int,
+        "nextToken": str,
+    },
+    total=False,
+)
+
+DescribeVcenterClientsResponseTypeDef = TypedDict(
+    "DescribeVcenterClientsResponseTypeDef",
+    {
+        "items": List["VcenterClientTypeDef"],
+        "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 DisconnectFromServiceRequestRequestTypeDef = TypedDict(
     "DisconnectFromServiceRequestRequestTypeDef",
     {
@@ -434,6 +469,7 @@ IdentificationHintsTypeDef = TypedDict(
         "awsInstanceID": str,
         "fqdn": str,
         "hostname": str,
+        "vmPath": str,
         "vmWareUuid": str,
     },
     total=False,
@@ -758,7 +794,7 @@ ResponseMetadataTypeDef = TypedDict(
         "RequestId": str,
         "HostId": str,
         "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, Any],
+        "HTTPHeaders": Dict[str, str],
         "RetryAttempts": int,
     },
 )
@@ -793,9 +829,11 @@ SourceServerResponseMetadataTypeDef = TypedDict(
         "isArchived": bool,
         "launchedInstance": "LaunchedInstanceTypeDef",
         "lifeCycle": "LifeCycleTypeDef",
+        "replicationType": ReplicationTypeType,
         "sourceProperties": "SourcePropertiesTypeDef",
         "sourceServerID": str,
         "tags": Dict[str, str],
+        "vcenterClientID": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
@@ -808,9 +846,11 @@ SourceServerTypeDef = TypedDict(
         "isArchived": bool,
         "launchedInstance": "LaunchedInstanceTypeDef",
         "lifeCycle": "LifeCycleTypeDef",
+        "replicationType": ReplicationTypeType,
         "sourceProperties": "SourcePropertiesTypeDef",
         "sourceServerID": str,
         "tags": Dict[str, str],
+        "vcenterClientID": str,
     },
     total=False,
 )
@@ -844,6 +884,13 @@ StartCutoverResponseTypeDef = TypedDict(
     },
 )
 
+StartReplicationRequestRequestTypeDef = TypedDict(
+    "StartReplicationRequestRequestTypeDef",
+    {
+        "sourceServerID": str,
+    },
+)
+
 _RequiredStartTestRequestRequestTypeDef = TypedDict(
     "_RequiredStartTestRequestRequestTypeDef",
     {
@@ -1013,3 +1060,27 @@ class UpdateReplicationConfigurationTemplateRequestRequestTypeDef(
     _OptionalUpdateReplicationConfigurationTemplateRequestRequestTypeDef,
 ):
     pass
+
+
+UpdateSourceServerReplicationTypeRequestRequestTypeDef = TypedDict(
+    "UpdateSourceServerReplicationTypeRequestRequestTypeDef",
+    {
+        "replicationType": ReplicationTypeType,
+        "sourceServerID": str,
+    },
+)
+
+VcenterClientTypeDef = TypedDict(
+    "VcenterClientTypeDef",
+    {
+        "arn": str,
+        "datacenterName": str,
+        "hostname": str,
+        "lastSeenDatetime": str,
+        "sourceServerTags": Dict[str, str],
+        "tags": Dict[str, str],
+        "vcenterClientID": str,
+        "vcenterUUID": str,
+    },
+    total=False,
+)
